summaryrefslogtreecommitdiff
path: root/scripts/build/companion_libs/100-gmp.sh
diff options
context:
space:
mode:
authorYann Diorcet <diorcet.yann@gmail.com>2012-11-16 14:25:57 (GMT)
committerYann Diorcet <diorcet.yann@gmail.com>2012-11-16 14:25:57 (GMT)
commitb43fdf40f1f90c4c313dda5b74955cc725a88b40 (patch)
tree70c65d158f49bc2c50fdbc3e4a61a7f62cbe747b /scripts/build/companion_libs/100-gmp.sh
parent1af4a119d20cd1f806262f5a951ba0a356da3d8a (diff)
scripts: add BUILD/HOST extra cflags/ldflags
On some hosts, and for certain toolchains (eg. toolchain targetting the upcoming Darwin), it may be necessary to pass arbitrary CFLAGS and/or LDFLAGS when building the components. And necessary infrastructure: - EXTRA_{CFLAGS,LDFLAGS}_FOR_{BUILD,HOST} as config options - pass those extra flags to components Fix-up a slight typo in elf2flt at the same time (misnamed cflags). Signed-off-by: Yann Diorcet <diorcet.yann@gmail.com> Message-Id: <d24043276c9243a35421.1353077450@macbook-smorlat.local> Patchwork-Id: 199645
Diffstat (limited to 'scripts/build/companion_libs/100-gmp.sh')
-rw-r--r--scripts/build/companion_libs/100-gmp.sh8
1 files changed, 7 insertions, 1 deletions
diff --git a/scripts/build/companion_libs/100-gmp.sh b/scripts/build/companion_libs/100-gmp.sh
index ebc095b..8674f16 100644
--- a/scripts/build/companion_libs/100-gmp.sh
+++ b/scripts/build/companion_libs/100-gmp.sh
@@ -37,6 +37,8 @@ do_gmp_for_build() {
gmp_opts+=( "host=${CT_BUILD}" )
gmp_opts+=( "prefix=${CT_BUILDTOOLS_PREFIX_DIR}" )
+ gmp_opts+=( "cflags=${CT_CFLAGS_FOR_BUILD}" )
+ gmp_opts+=( "ldflags=${CT_LDFLAGS_FOR_BUILD}" )
do_gmp_backend "${gmp_opts[@]}"
CT_Popd
@@ -53,6 +55,7 @@ do_gmp_for_host() {
gmp_opts+=( "host=${CT_HOST}" )
gmp_opts+=( "prefix=${CT_HOST_COMPLIBS_DIR}" )
gmp_opts+=( "cflags=${CT_CFLAGS_FOR_HOST}" )
+ gmp_opts+=( "ldflags=${CT_LDFLAGS_FOR_HOST}" )
do_gmp_backend "${gmp_opts[@]}"
CT_Popd
@@ -63,11 +66,13 @@ do_gmp_for_host() {
# Parameter : description : type : default
# host : machine to run on : tuple : (none)
# prefix : prefix to install into : dir : (none)
# cflags : host cflags to use : string : (empty)
do_gmp_backend() {
local host
local prefix
local cflags
+ local ldflags
local arg
for arg in "$@"; do
@@ -78,6 +83,7 @@ do_gmp_backend() {
CT_DoExecLog CFG \
CFLAGS="${cflags} -fexceptions" \
+ LDFLAGS="${ldflags}" \
"${CT_SRC_DIR}/gmp-${CT_GMP_VERSION}/configure" \
--build=${CT_BUILD} \
--host=${host} \
@@ -63,11 +66,13 @@ do_gmp_for_host() {
# host : machine to run on : tuple : (none)
# prefix : prefix to install into : dir : (none)
-# cflags : host cflags to use : string : (empty)
+# cflags : cflags to use : string : (empty)
+# ldflags : ldflags to use : string : (empty)
do_gmp_backend() {
local host